<?php

namespace App\Http\Controllers;

use Couchbase\UserSettings;
use Illuminate\Http\Request;
use App\{Activation,
    Fee,
    MasterPanel,
    MasterYear,
    MasterMonth,
    MasterItem,
    MasterGroup,
    MasterCountries,
    MasterRegisterType,
    MasterCompanyType};
use App\MemberExport;
use App\User;
use Illuminate\Support\Facades\DB;

class DownloadController extends Controller
{
    //
    public function exportData(Request $request)
    {
        if (authType() == 'company') {
            $exMessage = ['message' => "Invalid URL Link"];
            return view('404', compact('exMessage'));
        };
        $y_id = (isset($request->year) ? $request->year : '');
        $years = MasterYear::pluck('name', 'id')->toArray();
        $data = [];
        if ($y_id != '') {

            $panels = MasterPanel::pluck('name', 'id')->toArray();
            $groups = MasterGroup::pluck('name', 'id')->toArray();

            $items = MasterItem::select('*')->get()
                ->mapToGroups(function ($item, $key) {
                    return [$item['id'] => $item];
                })->toArray();
            $countryRegion = MasterCountries::select('*')->get()
                ->mapToGroups(function ($item, $key) {
                    return [$item['id'] => $item];
                })->toArray();
            $companyData = User::pluck('name', 'id')->toArray();
            $months = MasterMonth::pluck('name', 'id')->toArray();
            $rowData = MemberExport::where('year', $y_id)->select('*')->get()->toArray();

            foreach ($rowData as $key => $datum) {
                $temp = [];
                $temp['companyName'] = $companyData[$datum['user_id']];
                $temp['year'] = $years[$datum['year']];
                $temp['month'] = $months[$datum['month']];
                $temp['item'] = $items[$datum['item']][0]['name'];
                $temp['itemPanel'] = $panels[$items[$datum['item']][0]['panel']];
                $temp['itemGroup'] = $groups[$items[$datum['item']][0]['group']];
                $temp['hsCode'] = $items[$datum['item']][0]['hs_code'];
                $temp['country'] = $countryRegion[$datum['country']][0]['name'];
                $temp['region'] = $countryRegion[$datum['country']][0]['region'];

                $temp['amount'] = $datum['value_in_rs'];
                $temp['created_at'] = $datum['created_at'];

                $data[] = $temp;
            }
        }
        return view('download-export-data', compact('years', 'y_id', 'data'));
    }

    public function memberDatabase(Request $request)
    {
        if (authType() == 'company') {
            $exMessage = ['message' => "Invalid URL Link"];
            return view('404', compact('exMessage'));
        };
        $mRegisterType = MasterRegisterType::pluck('name', 'id')->toArray();
        $mCompanyType = MasterCompanyType::pluck('name', 'id')->toArray();
        $mPanels = MasterPanel::pluck('name', 'id')->toArray();
        $months = MasterMonth::pluck('name', 'id')->toArray();
        $years = MasterYear::pluck('name', 'id')->toArray();

        $activation = Activation::where('active', '1')
            ->select('user_id', 'file_number', 'registration_number', 'registration_year', 'registration_date',
                'validity_date','dgft_status')
            ->get()
            ->mapToGroups(function ($item, $key) {
                return [$item['user_id'] => $item];
            })->toArray();

        $userData = User::where(['type' => '1', 'active' => '1'])
            //->orderColumn('name', '-name $1')
            ->select('*')->get()->toArray();
//dd($userData);
        // Get First export user part
        $exportCols = [];
        $usersExport = MemberExport::select(DB::raw("user_id, MAX(abs(year)) as maxYear"))
            ->where('month','>', 0)
            ->groupBy('user_id')->get()
            ->mapToGroups(function ($item, $key) {
                return [$item['user_id'] => $item];
            })
            ->toArray();
        if (count($usersExport) > 0) {
            foreach ($usersExport as $key => $data) {
                $temp = MemberExport::where(['user_id' => $key, 'year' => $data[0]['maxYear']])
//                    ->where('month','>', 0)
                    ->select(DB::raw("max(month) as MaxMonth, sum(value_in_rs) as totalRs"))

                    ->get()->toArray();
                $exportCols[$key] = ['year'    => $data[0]['maxYear'],
                                     'month'   => $temp[0]['MaxMonth'],
                                     'totalRs' => $temp[0]['totalRs']
                ];
            }
//            dd($exportCols);
            unset($temp);
        }

        // Get fee part
        $feeCols = [];
        $usersFee = Fee::select( DB::raw("user_id, MAX(year) as maxYear"))
            ->where('paid_fee','>', 0)
            ->groupBy('user_id')->get()
            ->mapToGroups(function ($item, $key) {
                return [$item['user_id'] => $item];
            })
            ->toArray();

//        dd($usersFee);
        if (count($usersFee) > 0) {
            foreach ($usersFee as $key => $data) {
                $temp = Fee::where(['user_id' => $key, 'year' => $data[0]['maxYear']/*, 'balance_paid_year'=>$data[0]['balance_paid_year']*/])
//                    ->where('upto','>', 0)
                    ->select(DB::raw("paid_year,paid_fee, sum(applicable_fee) as applicableFee"))
                    ->groupBy('paid_year','paid_fee')
                    ->get()->toArray();
                $feeCols[$key] = ['year'=>$data[0]['maxYear'], 'paid_year'=>$temp[0]['paid_year'], 'aplicableFee'=>$temp[0]['applicableFee'], 'paid_fee'=>$temp[0]['paid_fee']];
            }

        }
//        dd($feeCols);
//        dd($feeCols);
        return view('download-members-data',
            compact('userData', 'mRegisterType', 'mCompanyType', 'mPanels', 'activation', 'exportCols', 'years',
                'months','feeCols'));
    }
}
