<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\{MasterPanel,
    MasterCountries,
    MasterCompanyType,
    MasterYear,
    MasterMonth,
    MasterGroup,
    MasterItem,
    MasterMembershipFees,
    MasterRegisterType};

class MastersController extends Controller
{
    //
    public function __construct()
    {
        $this->middleware('auth');
    }

    public function membershipfeesData()
    {
        return MasterMembershipFees::select('*')->get()->toArray();
    }

    public function membershipfees(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['col1'])) {
            $request->validate([
                'col1'   => 'required|min:1|max:500',
                'col2'   => 'required|min:1|max:500',
                'col3'   => 'required|min:1|max:500',
                'col4'   => 'required|min:1|max:500',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $update = MasterMembershipFees::where('id', $_POST['id'])
                        ->update([
                            'col1'   => $_POST['col1'],
                            'col2'   => $_POST['col2'],
                            'col3'   => $_POST['col3'],
                            'col4'   => $_POST['col4'],
                            'active' => $_POST['active']
                        ]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Membership Fees Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $data = $this->membershipfeesData();
                return view('master.membershipfees', compact('exMessage', 'data'));
            }
            try {
                $insert = MasterMembershipFees::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Membership Fees Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $data = $this->membershipfeesData();
            return view('master.membershipfees', compact('exMessage', 'data'));
        } else {
            $data = $this->membershipfeesData();
            return view('master.membershipfees', compact('data'));
        }
    }

    public function groupMasterData()
    {
        return MasterGroup::select('*')->get()->toArray();
    }

    public function groupMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name'   => 'required|min:1|max:255',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $update = MasterGroup::where('id', $_POST['id'])
                        ->update(['name' => $_POST['name'], 'active' => $_POST['active']]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Group Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $data = $this->groupMasterData();
                return view('master.group', compact('exMessage', 'data'));
            }

            try {
                $insert = MasterGroup::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Group Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $data = $this->groupMasterData();
            return view('master.group', compact('exMessage', 'data'));
        } else {
            $data = $this->groupMasterData();
            return view('master.group', compact('data'));
        }
    }

    public function panelMasterData()
    {
        return MasterPanel::select('*')->get()->toArray();
    }

    public function panelMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name'   => 'required|min:3|max:255',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $updatePanel = MasterPanel::where('id', $_POST['id'])
                        ->update(['name' => $_POST['name'], 'active' => $_POST['active']]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Panel Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $fetchPanelData = $this->panelMasterData();
                return view('master.panel', compact('exMessage', 'fetchPanelData'));
            }

            try {
                $insertPanel = MasterPanel::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Panel Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $fetchPanelData = $this->panelMasterData();
            return view('master.panel', compact('exMessage', 'fetchPanelData'));
        } else {
            $fetchPanelData = $this->panelMasterData();
            return view('master.panel', compact('fetchPanelData'));
        }
    }

    public function countryMasterData()
    {
        return $fetchPanelData = MasterCountries::select('*')->get()->toArray();
    }

    public function countryMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name'   => 'required|min:3|max:255',
                'region' => 'required|min:3|max:255',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $insertPanel = MasterCountries::where('id', $_POST['id'])
                        ->update([
                            'name'   => $_POST['name'],
                            'region' => $_POST['region'],
                            'active' => $_POST['active']
                        ]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Country Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $fetchCountryData = $this->countryMasterData();
                return view('master.country', compact('exMessage', 'fetchCountryData'));
            }
//
            try {
                $insertPanel = MasterCountries::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Country Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $fetchCountryData = $this->countryMasterData();
            return view('master.country', compact('exMessage', 'fetchCountryData'));
        } else {
            $fetchCountryData = $this->countryMasterData();
            return view('master.country', compact('fetchCountryData'));
        }

        return view('master.country', compact('fetchCountryData'));
    }

    public function itemMasterData()
    {
        return MasterItem::select('*')->get()->toArray();
    }

    public function itemMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        $panel = MasterPanel::pluck('name', 'id')->toArray();
        $group = MasterGroup::pluck('name', 'id')->toArray();
        if (isset($_POST['name'])) {
            $request->validate([
                'panel'   => 'required',
                'group'   => 'required',
                'hs_code' => 'required',
                'name'    => 'required|min:1|max:255',
                'active'  => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $update = MasterItem::where('id', $_POST['id'])
                        ->update([
                            'name'    => $_POST['name'],
                            'panel'   => $_POST['panel'],
                            'group'   => $_POST['group'],
                            'hs_code' => $_POST['hs_code'],
                            'active'  => $_POST['active']
                        ]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Item Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $data = $this->itemMasterData();
                return view('master.item', compact('exMessage', 'data', 'panel', 'group'));
            }
            try {
                $insert = MasterItem::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Item Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $data = $this->itemMasterData();
            return view('master.item', compact('exMessage', 'data', 'panel', 'group'));
        } else {
            $data = $this->itemMasterData();
            return view('master.item', compact('data', 'panel', 'group'));
        }
    }

    public function monthMasterData()
    {
        return MasterMonth::select('*')->get()->toArray();
    }

    public function monthMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name'   => 'required|min:3|max:10',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $update = MasterMonth::where('id', $_POST['id'])
                        ->update(['name' => $_POST['name'], 'active' => $_POST['active']]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Month Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $data = $this->monthMasterData();
                return view('master.month', compact('exMessage', 'data'));
            }

            try {
                $insert = MasterMonth::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Month Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $data = $this->monthMasterData();
            return view('master.month', compact('exMessage', 'data'));
        } else {
            $data = $this->monthMasterData();
            return view('master.month', compact('data'));
        }
    }

    public function yearMasterData()
    {
        return MasterYear::select('*')->get()->toArray();
    }

    public function yearMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name'   => 'required|min:4|max:255',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $update = MasterYear::where('id', $_POST['id'])
                        ->update([
                            'name'   => $_POST['name'],
                            'active' => $_POST['active']
                        ]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Year Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $data = $this->yearMasterData();
                return view('master.year', compact('exMessage', 'data'));
            }
            try {
                $insert = MasterYear::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Year Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $data = $this->yearMasterData();
            return view('master.year', compact('exMessage', 'data'));
        } else {
            $data = $this->yearMasterData();
            return view('master.year', compact('data'));
        }
        return view('master.year');
    }

    public function companyTypeMasterData()
    {
        return MasterCompanyType::select('*')->get()->toArray();
    }

    public function companyTypeMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name'   => 'required|min:3|max:255',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $updatePanel = MasterCompanyType::where('id', $_POST['id'])
                        ->update(['name' => $_POST['name'], 'active' => $_POST['active']]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'Master Panel Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $fetchCompanyTypeData = $this->companyTypeMasterData();
                return view('master.company-type', compact('exMessage', 'fetchCompanyTypeData'));
            }

            try {
                $insertPanel = MasterCompanyType::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'Master Panel Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $fetchCompanyTypeData = $this->companyTypeMasterData();
            return view('master.company-type', compact('exMessage', 'fetchCompanyTypeData'));
        } else {
            $fetchCompanyTypeData = $this->companyTypeMasterData();
            return view('master.company-type', compact('fetchCompanyTypeData'));
        }
        return view('master.company-type', compact('fetchCompanyTypeData'));
    }
    public function registerTypeMasterData()
    {
        return MasterRegisterType::select('*')->get()->toArray();
    }
    public function registerTypeMaster(Request $request)
    {
        if (authType()=='company') {
            $exMessage=['message'=>"Invalid URL Link"];
            return view('404',compact('exMessage'));
        };
        if (isset($_POST['name'])) {
            $request->validate([
                'name' => 'required|min:3|max:255',
                'active' => 'required',
            ]);
            $exMessage = [];
            if (!empty($_POST['id'])) {
                try {
                    $updatePanel = MasterRegisterType::where('id', $_POST['id'])
                        ->update(['name' => $_POST['name'], 'active' => $_POST['active']]);
                    $exMessage['process'] = true;
                    $exMessage['message'] = 'register Panel Updated Successfully';
                } catch (\Illuminate\Database\QueryException $ex) {
                    $exMessage['process'] = false;
                    $exMessage['message'] = $ex->errorInfo[2];
                }
                $fetchRegisterTypeData = $this->registerTypeMasterData();
                return view('master.register-type', compact('exMessage', 'fetchRegisterTypeData'));
            }

            try {
                $insertPanel = MasterRegisterType::create($request->all());
                $exMessage['process'] = true;
                $exMessage['message'] = 'register Master Panel Added Successfully';
            } catch (\Illuminate\Database\QueryException $ex) {
                $exMessage['process'] = false;
                $exMessage['message'] = $ex->errorInfo[2];
            }
            $fetchRegisterTypeData = $this->registerTypeMasterData();
            return view('master.register-type', compact('exMessage', 'fetchRegisterTypeData'));
        } else {
            $fetchRegisterTypeData = $this->registerTypeMasterData();
            return view('master.register-type', compact('fetchRegisterTypeData'));
        }
        return view('master.register-type', compact('fetchRegisterTypeData'));


    }

}
