@extends('layouts.admin')
@push('extra-css')
    <link href="{{ asset('bower_components/datatables.net-bs/css/dataTables.bootstrap.min.css') }}" rel="stylesheet">
@endpush
@section('content')
    <section class="content">
        <div class="row">
            <div class="col-md-2"></div>
            <div class="col-md-8">
                @if(isset($exMessage['process']))
                    <div class="alert alert-{{($exMessage['process'] ? 'success':'danger')}} alert-dismissible">
                        <button type="button" class="close" data-dismiss="alert" aria-hidden="true">&times;</button>
                        <h4><i class="icon fa fa-{{($exMessage['process'] ? 'check':'ban')}}"></i> Alert!</h4>
                        {{$exMessage['message']}}
                    </div>
            @endif
            <!-- Horizontal Form -->
                <div class="box box-info">
                    <div class="box-header with-border">
                        <h3 class="box-title">Master Year</h3>
                    </div>
                    <!-- form start -->
                    <form method="POST" class="form-horizontal" action="{{ route('master.year') }}">
                        {{ csrf_field() }}
                        <div class="box-body">
                            <div class="form-group">
                                <label for="panelName" class="col-sm-2 control-label">Name</label>
                                <div class="col-sm-10">
                                    <input type="text" class="form-control" name="name" id="name"
                                           value="{{ old('name') }}"
                                           placeholder="Name" required>
                                    @error('year_1')
                                    <span style="color: red;">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                            <div class="form-group">
                                <label for="panelName" class="col-sm-2 control-label">Active</label>
                                <div class="col-sm-10">
                                    <select class="form-control" name="active" id="active" required>
                                        <option value="">- Choose -</option>
                                        <option value="0">In-Active</option>
                                        <option value="1">Active</option>
                                    </select>
                                    @error('active')
                                    <span style="color: red;">
                                        <strong>{{ $message }}</strong>
                                    </span>
                                    @enderror
                                </div>
                            </div>
                        </div>
                        <input type="hidden" name="id" id="modifyId">
                        <div class="box-footer">
                            <button type="reset" id="resetn" class="btn btn-default">Reset</button>
                            <button type="submit" class="btn btn-info pull-right">SAVE</button>
                        </div>
                        <!-- /.box-footer -->
                    </form>
                </div>
            </div>
            <div class="col-md-2"></div>
        </div>
        <div class="box">
            <div class="box-header">
                <h3 class="box-title">Master Year List</h3>
            </div>
            <!-- /.box-header -->
            <div class="box-body">
                <table id="example1" class="table table-bordered table-striped">
                    <thead>
                    <tr>
                        <th>ID</th>
                        <th>Name</th>
                        <th>Created At</th>
                        <th>Status</th>
                        <th>Modify</th>
                    </tr>
                    </thead>
                    <tbody>
                    @foreach($data as $key => $data)
                        <tr>
                            <td>{{$data['id']}}</td>
                            <td>{{$data['name']}}</td>
                            <td>{{$data['created_at']}}</td>
                            <td>
                                <span class='label label-{{($data['active'] == 1?'success':'danger')}}'>{{($data['active'] == 1?'Active':'In-Active')}}</span>
                            </td>
                            <td>
                                <button type="button" id="modifyMe" class="btn-info btn-xs mClass"
                                        data_val="{{base64_encode($data['id']."!~#~!".$data['name']."!~#~!".$data['active'])}}">
                                    <i class="fa fa-edit"></i></button>
                            </td>
                        </tr>
                    @endforeach
                    </tbody>
                </table>
            </div>
            <!-- /.box-body -->
            <div>&nbsp;&nbsp;<code><b>NOTE:</b></code> <small>YEAR NAME IS UNIQUE FILED IN THE TABLE</small></div>
        </div>
    </section>
@endsection
@push('extra-script')
    <script src="{{ asset('bower_components/datatables.net/js/jquery.dataTables.min.js') }}"></script>
    <script src="{{ asset('bower_components/datatables.net-bs/js/dataTables.bootstrap.min.js') }}"></script>
    <script>
        $(document).ready(function () {
            $("#resetn").click(function () {
                $("#modifyId").val('');
            });

            $(".mClass").click(function () {
                var Cdata = atob($(this).attr('data_val')).split('!~#~!');
                if (Cdata.length == 3) {
                    $("#modifyId").val(Cdata[0]);
                    $("#name").val(Cdata[1]);
                    $("#active").val(Cdata[2]);
                    $("#name").focus();
                }
            });
            $('#example1').DataTable();
        });
    </script>
@endpush
